@@ -36,7 +36,6 @@ typedef enum {
 	RegOK,
 	RegNot,
 	NotEqual,
-	ArraySize,
 	StringLess,
 	StringLessEqual,
 	StringGreater,
@@ -63,6 +62,7 @@ typedef enum {
 	FunctionDecl,
 	Method,
 	Assign,
+	ArraySize,
 	Is,
 	IsNot,
 	Not,
@@ -91,6 +91,7 @@ typedef enum {
 	StateDecl,
 	UseDecl,
 	UsedName,
+	RequiredName,
 	IfStmt,
 	ElseStmt,
 	ElsifStmt,
@@ -146,6 +147,7 @@ typedef enum {
 	RegDecl,
 	RegMatch,
 	RegDelim,
+	HandleDelim,
 	RegMiddleDelim,
 	RegAllReplace,
 	RegReplace,
@@ -171,6 +173,7 @@ typedef enum {
 	VersionString,
 	HereDocumentTag,
 	HereDocumentRawTag,
+	HereDocumentExecTag,
 	RawHereDocument,
 	HereDocument,
 	HereDocumentEnd,
@@ -199,6 +202,9 @@ typedef enum {
 	Argument,
 	List,
 	Default,
+	Pod,
+	Comment,
+	WhiteSpace,
 	Undefined
 } Type;
 }
@@ -226,7 +232,7 @@ typedef enum {
 	Continue,
 	Do,
 	Break,
-	Term,
+	Module,
 	Stmt,
 	DefaultStmt,
 	Comma,
@@ -234,6 +240,7 @@ typedef enum {
 	StmtEnd,
 	Symbol,
 	Modifier,
+	Term,
 	Namespace,
 	Package,
 	Class,
@@ -244,6 +251,7 @@ typedef enum {
 	Ref,
 	Get,
 	Set,
+	Verbose,
 	Undefined
 } Kind;
 }
