@@ -20,6 +20,10 @@ Annotator::Annotator(void)
 
 void Annotator::annotate(LexContext *ctx, Token *tk)
 {
+	// Ignore WhiteSpace tokens to annotate
+	if (tk->info.type == WhiteSpace) {
+		return;
+	}
 	if (tk->info.type != Undefined) {
 		ctx->prev_type = tk->info.type;
 		return;
@@ -78,7 +82,7 @@ void Annotator::annotateMethod(LexContext *ctx, const string &, Token *tk, Token
 void Annotator::annotateKey(LexContext *ctx, const string &, Token *tk, TokenInfo *info)
 {
 	Token *prev_before_tk = ctx->tmgr->beforePreviousToken(tk);
-	TokenType::Type prev_before_type = (prev_before_tk) ? prev_before_tk->info.type : Undefined; 
+	TokenType::Type prev_before_type = (prev_before_tk) ? prev_before_tk->info.type : Undefined;
 	Token *next_tk = ctx->tmgr->nextToken(tk);
 	if (prev_before_type != Function &&
 		ctx->prev_type == LeftBrace && next_tk &&
