@@ -36,7 +36,6 @@ TokenInfo decl_tokens[] = {
 	{Enum::Token::Type::RegOK, Enum::Token::Kind::Operator, "RegOK", "=~"},
 	{Enum::Token::Type::RegNot, Enum::Token::Kind::Operator, "RegNot", "!~"},
 	{Enum::Token::Type::NotEqual, Enum::Token::Kind::Operator, "NotEqual", "!="},
-	{Enum::Token::Type::ArraySize, Enum::Token::Kind::Operator, "ArraySize", "$#"},
 	{Enum::Token::Type::StringLess, Enum::Token::Kind::Operator, "StringLess", "lt"},
 	{Enum::Token::Type::StringLessEqual, Enum::Token::Kind::Operator, "StringLessEqual", "le"},
 	{Enum::Token::Type::StringGreater, Enum::Token::Kind::Operator, "StringGreater", "gt"},
@@ -65,6 +64,7 @@ TokenInfo decl_tokens[] = {
 	{Enum::Token::Type::FunctionDecl, Enum::Token::Kind::Decl, "FunctionDecl", "sub"},
 	{Enum::Token::Type::Method, Enum::Token::Kind::Function, "Method", ""},
 	{Enum::Token::Type::Assign, Enum::Token::Kind::Assign, "Assign", "="},
+	{Enum::Token::Type::ArraySize, Enum::Token::Kind::SingleTerm, "ArraySize", "$#"},
 	{Enum::Token::Type::Is, Enum::Token::Kind::SingleTerm, "Is", ""},
 	{Enum::Token::Type::IsNot, Enum::Token::Kind::SingleTerm, "IsNot", "!"},
 	{Enum::Token::Type::Not, Enum::Token::Kind::SingleTerm, "Not", "not"},
@@ -476,6 +476,9 @@ TokenInfo decl_tokens[] = {
 	{Enum::Token::Type::Argument, Enum::Token::Kind::Term, "Argument", ""},
 	{Enum::Token::Type::List, Enum::Token::Kind::Term, "List", ""},
 	{Enum::Token::Type::Default, Enum::Token::Kind::Term, "Default", "undef"},
+	{Enum::Token::Type::Pod, Enum::Token::Kind::Verbose, "Pod", ""},
+	{Enum::Token::Type::Comment, Enum::Token::Kind::Verbose, "Comment", ""},
+	{Enum::Token::Type::WhiteSpace, Enum::Token::Kind::Verbose, "WhiteSpace", ""},
 	{Enum::Token::Type::Undefined, Enum::Token::Kind::Undefined, "Undefined", ""}
 };
 
@@ -514,7 +517,6 @@ TokenInfo type_to_info[] = {
 	{Enum::Token::Type::RegOK, Enum::Token::Kind::Operator, "RegOK", "=~"},
 	{Enum::Token::Type::RegNot, Enum::Token::Kind::Operator, "RegNot", "!~"},
 	{Enum::Token::Type::NotEqual, Enum::Token::Kind::Operator, "NotEqual", "!="},
-	{Enum::Token::Type::ArraySize, Enum::Token::Kind::Operator, "ArraySize", "$#"},
 	{Enum::Token::Type::StringLess, Enum::Token::Kind::Operator, "StringLess", "lt"},
 	{Enum::Token::Type::StringLessEqual, Enum::Token::Kind::Operator, "StringLessEqual", "le"},
 	{Enum::Token::Type::StringGreater, Enum::Token::Kind::Operator, "StringGreater", "gt"},
@@ -541,6 +543,7 @@ TokenInfo type_to_info[] = {
 	{Enum::Token::Type::FunctionDecl, Enum::Token::Kind::Decl, "FunctionDecl", "sub"},
 	{Enum::Token::Type::Method, Enum::Token::Kind::Function, "Method", ""},
 	{Enum::Token::Type::Assign, Enum::Token::Kind::Assign, "Assign", "="},
+	{Enum::Token::Type::ArraySize, Enum::Token::Kind::SingleTerm, "ArraySize", "$#"},
 	{Enum::Token::Type::Is, Enum::Token::Kind::SingleTerm, "Is", ""},
 	{Enum::Token::Type::IsNot, Enum::Token::Kind::SingleTerm, "IsNot", "!"},
 	{Enum::Token::Type::Not, Enum::Token::Kind::SingleTerm, "Not", "not"},
@@ -680,6 +683,9 @@ TokenInfo type_to_info[] = {
 	{Enum::Token::Type::Argument, Enum::Token::Kind::Term, "Argument", ""},
 	{Enum::Token::Type::List, Enum::Token::Kind::Term, "List", ""},
 	{Enum::Token::Type::Default, Enum::Token::Kind::Term, "Default", "undef"},
+	{Enum::Token::Type::Pod, Enum::Token::Kind::Verbose, "Pod", ""},
+	{Enum::Token::Type::Comment, Enum::Token::Kind::Verbose, "Comment", ""},
+	{Enum::Token::Type::WhiteSpace, Enum::Token::Kind::Verbose, "WhiteSpace", ""},
 	{Enum::Token::Type::Undefined, Enum::Token::Kind::Undefined, "Undefined", ""}
 };
 
